@@ -10,8 +10,9 @@ from redbot.core.i18n import Translator
 from redbot.core.utils.chat_formatting import humanize_number
 from redbot.vendored.discord.ext import menus
 
-from pylav import Query, Track
+from pylav.query import Query
 from pylav.sql.models import PlaylistModel
+from pylav.tracks import Track
 from pylav.types import CogT
 from pylav.utils import AsyncIter
 
